@@ -1,5 +1,6 @@
 //! This module implements parsers for RestructuredText hyperlinks.
 #![allow(dead_code)]
+#![allow(clippy::type_complexity)]
 
 use crate::parser::parse::LABEL_LEN_MAX;
 use crate::parser::Link;
@@ -127,7 +128,7 @@ fn rst_parse_text2target(
         };
 
         // Assure that the next char is not`_`.
-        if i != "" {
+        if !i.is_empty() {
             let _ = nom::combinator::not(nom::character::complete::char('_'))(i)?;
         };
 
@@ -360,14 +361,12 @@ fn rst_label2target(label: bool, i: &str) -> nom::IResult<&str, (Cow<str>, Cow<s
         Cow::Borrowed(s) => {
             let (_, (ls, lt)) = if !block_header_is__ {
                 rst_parse_label2target(label)(s)?
+            } else if label {
+                // This is supposed to be a label.
+                ("", ("_", rst_parse_simple_label(s)?.1))
             } else {
-                if label {
-                    // This is supposed to be a label.
-                    ("", ("_", rst_parse_simple_label(s)?.1))
-                } else {
-                    // This is supposed to be a destination (url).
-                    ("", ("_", s))
-                }
+                // This is supposed to be a destination (url).
+                ("", ("_", s))
             };
             // If the target is a destination (not a label), the last char must not be `_`.
             if !label {
@@ -382,15 +381,13 @@ fn rst_label2target(label: bool, i: &str) -> nom::IResult<&str, (Cow<str>, Cow<s
         Cow::Owned(strg) => {
             let (_, (ls, lt)) = if !block_header_is__ {
                 rst_parse_label2target(label)(&strg).map_err(my_err)?
+            } else if label {
+                // This is supposed to be a label.
+                let s = rst_parse_simple_label(&strg).map_err(my_err)?.1;
+                ("", ("_", s))
             } else {
-                if label {
-                    // This is supposed to be a label.
-                    let s = rst_parse_simple_label(&strg).map_err(my_err)?.1;
-                    ("", ("_", s))
-                } else {
-                    // This is supposed to be a destination (url).
-                    ("", ("_", strg.as_str()))
-                }
+                // This is supposed to be a destination (url).
+                ("", ("_", strg.as_str()))
             };
             // If the target is a destination (not a label), the last char must not be `_`.
             if !label {
@@ -479,7 +476,7 @@ fn rst_parse_simple_label(i: &str) -> nom::IResult<&str, &str> {
             // Strip two `__` from result.
             r = &r[..r.len() - 2];
         // Is `r` ending with `_`? There should be at least 1 byte: `"_".len()`.
-        } else if r.len() >= 1 && r.is_char_boundary(r.len() - 1) && &r[r.len() - 1..] == "_" {
+        } else if !r.is_empty() && r.is_char_boundary(r.len() - 1) && &r[r.len() - 1..] == "_" {
             // Remaining bytes.
             i = k;
             // Strip `_` from result.
@@ -556,13 +553,13 @@ fn rst_explicit_markup_block<'a>(
         )(i)?;
 
         let (j, v) = nom::multi::separated_list1(
-            indent(&wsp1, &wsp2),
+            indent(wsp1, wsp2),
             nom::character::complete::not_line_ending,
         )(i)?;
 
         // If the block consists of only one line return now.
         if v.len() == 1 {
-            return Ok((j, Cow::Borrowed(v[0].clone())));
+            return Ok((j, Cow::Borrowed(v[0])));
         };
 
         let mut s = String::new();
@@ -609,7 +606,7 @@ fn rst_escaped_link_text_transform(i: &str) -> IResult<&str, Cow<str>> {
 fn remove_whitespace(i: &str) -> IResult<&str, Cow<str>> {
     let mut res = Cow::Borrowed("");
     let mut j = i;
-    while j != "" {
+    while !j.is_empty() {
         let (k, _) = nom::character::complete::multispace0(j)?;
         let (k, s) = nom::bytes::complete::escaped(
             nom::character::complete::none_of("\\\r\n \t"),
@@ -660,7 +657,7 @@ fn rst_escaped_link_destination_transform(i: &str) -> IResult<&str, Cow<str>> {
     if s == i {
         Ok(("", Cow::Borrowed(i)))
     } else {
-        Ok(("", Cow::Owned(s.to_owned())))
+        Ok(("", Cow::Owned(s)))
     }
 }
 
